mfs

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 17, 2022 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CopyFile

func CopyFile(source, dest string) (err error)

CopyFile from `source` to `dest`

func GetFileSize

func GetFileSize(filename string) (int64, error)

GetFileSize return the size of the file as bytes.

func GetParentDir

func GetParentDir(path string) (string, error)

GetParentDir returns the path of parent directory.

func IsDir

func IsDir(path string) bool

IsDir reports whether the target path is a directory.

func IsFile

func IsFile(path string) bool

IsFile reports whether the target path is a file.

func IsFileExists

func IsFileExists(path string) bool

IsFileExists reports whether the file exists.

func IsPathExists

func IsPathExists(path string) bool

IsPathExists reports whether the file or directory exists.

func SelfDir

func SelfDir() (path string, err error)

SelfDir returns The directory that contains the executable file. If current executable is a symbolic link, Returns the real path to the directory that contains the executable.

Types

This section is empty.

Jump to